@@ -5,7 +5,8 @@ import requests
 
 from bs4 import BeautifulSoup
 from .toolkits.telegram import bot_messalert
-from .network import PapaPhone, mail2gmail
+from .network import PapaPhone
+
 
 def alltasks():
     pass
@@ -14,7 +15,7 @@ def alltasks():
 def papa_phone_dataflow():
     value, unit = PapaPhone().remain_flow()
     msg = f'papa cellphone data flow {value} {unit}'
-    mail2gmail(subject='日常流量提醒', message=msg)
+    bot_messalert('日常流量提醒\n' + msg)
 
 
 class HappyXiao:
