@@ -10,6 +10,8 @@ from dofast.toolkits.telegram import YahooMail
 from dofast.logger import Logger
 from dofast.config import decode
 
+from .toolkits.telegram import bot_messalert
+
 socket.setdefaulttimeout(30)
 
 logger = Logger('/var/log/phone.log')
@@ -63,10 +65,10 @@ class PapaPhone:
         if flow == -1:
             self.entry(retry - 1)
         elif flow < 1 or unit == 'MB':
-            subject = 'Papa手机流量充值提醒'
-            message = f'Papa 的手机流量还剩余 {flow} {unit}，可以充值了。'
+            # subject = 'Papa手机流量充值提醒 \n'
+            message = f'Papa手机流量还剩余 {flow} {unit}，可以充值了。'
             logger.info('\n'.join((receiver, subject, message)))
-            YahooMail().send(receiver, subject, message)
+            bot_messalert(subject + message)
 
 
 class Network:
